@@ -11,6 +11,7 @@ from pydantic import ValidationError
 from rich.console import Console
 from rich.table import Table
 from sqlalchemy import create_engine, select
+from sqlalchemy.exc import DBAPIError
 from sqlalchemy.orm import sessionmaker
 
 from fief import __version__
@@ -89,9 +90,39 @@ def migrate_workspaces():
                 workspace.alembic_revision = alembic_revision
                 session.add(workspace)
                 session.commit()
-                typer.secho(f"Done!")
+                typer.secho("Done!")
             except WorkspaceDatabaseConnectionError:
-                typer.secho(f"Failed!", fg="red", err=True)
+                typer.secho("Failed!", fg="red", err=True)
+
+
+@workspaces.command("init-email-templates")
+def init_email_templates():
+    """Ensure email templates are initialized in each workspace."""
+    from fief.models import Workspace
+    from fief.services.email_template.initializer import init_email_templates
+
+    settings = get_settings()
+
+    loop = asyncio.new_event_loop()
+    asyncio.set_event_loop(loop)
+
+    url, connect_args = settings.get_database_connection_parameters(False)
+    engine = create_engine(url, connect_args=connect_args)
+    Session = sessionmaker(engine)
+    with Session() as session:
+        workspace_db = WorkspaceDatabase()
+        latest_revision = workspace_db.get_latest_revision()
+        workspaces = select(Workspace).where(
+            Workspace.alembic_revision == latest_revision
+        )
+        for [workspace] in session.execute(workspaces):
+            assert isinstance(workspace, Workspace)
+            typer.secho(f"Checking {workspace.name}... ", bold=True, nl=False)
+            try:
+                loop.run_until_complete(init_email_templates(workspace))
+                typer.secho("Done!")
+            except (ConnectionError, DBAPIError):
+                typer.secho("Failed!", fg="red", err=True)
 
 
 @workspaces.command("create-main")
@@ -230,7 +261,7 @@ def info():
         settings = get_settings()
 
         typer.secho(f"Fief version: {__version__}", bold=True)
-        typer.secho(f"Settings", bold=True)
+        typer.secho("Settings", bold=True)
         for key, value in settings.dict().items():
             typer.echo(f"{key}: {value}")
     except ValidationError as e:
@@ -303,7 +334,7 @@ def run_server(
         )
         if user_email is None:
             typer.secho(
-                f"Main Fief user email not provided in settings. Skipping its creation.",
+                "Main Fief user email not provided in settings. Skipping its creation.",
                 fg=typer.colors.YELLOW,
             )
         else:
@@ -328,7 +359,7 @@ def run_server(
                     f"Invalid main Fief user password: {e.reason}", fg=typer.colors.RED
                 )
                 raise typer.Exit(code=1) from e
-            except UserAlreadyExists as e:
+            except UserAlreadyExists:
                 typer.echo("Main Fief user already exists")
 
     uvicorn.run("fief.app:app", host=host, port=port)
